@@ -3,7 +3,6 @@ package MyApp;
 use strict;
 use warnings;
 use Kossy;
-use Cookie::Baker;
 
 get "/" => sub {
     my ( $self, $c )  = @_;
@@ -17,14 +16,25 @@ get "/uri_for" => sub {
 
 router [qw/GET POST/] => "/bar" => sub {
     my ( $self, $c )  = @_;
-    $c->response->body("ok");
+    my $param = $c->req->param('q');
+    $c->response->body("ok => " . $param);
 };
 
 get '/set_cookie' => sub {
     my ( $self, $c )  = @_;
-    $c->response->cookies->{foo} = '123456';
+    $c->response->cookies->{'foo'} = '123 456';
     $c->response->body("cookies are baked");
 };
- 
+
+post '/json_api' => sub {
+    my ( $self, $c )  = @_;
+    $c->env->{'kossy.request.parse_json_body'} = 1;
+    $c->res->header('X-Frame-Options','SAMEORIGIN');
+    my $param = $c->req->param('q');
+    $c->response->body("json_api:". $param);
+};
+
+
+
 1;
 
